#include "munixapplicationicon.h"

#include <QCoreApplication>
#include <QDebug>
#include <QDir>
#include <QFileInfo>
#include <QRegularExpression>
#include <QTextStream>

class MUnixApplicationIcon::Private
{
public:
    QString filename;
    QString iconFilename;
};

MUnixApplicationIcon::MUnixApplicationIcon(QObject *parent) :
    QObject(parent),
    priv(new Private)
{
    if (QCoreApplication::applicationName().isEmpty()) {
        qWarning("You have to set the QCoreApplication::applicationName before instantiating UnixAutostart(). It won't do anything.");
        return;
    }

    priv->filename = QString(QLatin1String("%1/.local/share/applications/%2.desktop"))
                        .arg(qEnvironmentVariable("HOME"))
                        .arg(QCoreApplication::applicationName().remove(QRegularExpression(QLatin1String("\\s*"))));

    priv->iconFilename = QString(QLatin1String("%1/.local/share/icons/%2.png"))
                            .arg(qEnvironmentVariable("HOME"))
                            .arg(QCoreApplication::applicationName().remove(QRegularExpression(QLatin1String("\\s*"))));
}

MUnixApplicationIcon::~MUnixApplicationIcon()
{

}

bool MUnixApplicationIcon::isGLoballyEnabled() const
{
    QStringList paths;
    paths << QLatin1String("/usr/share/applications/%1.desktop");
    paths << QLatin1String("/usr/local/share/applications/%1.desktop");

    foreach(const QString path, paths) {
        QString filename = path.arg(QCoreApplication::applicationName().remove(QRegularExpression(QLatin1String("\\s*"))));

        QFile file(filename);
        if (file.exists()) {
            return true;
        }
    }

    return false;
}

bool MUnixApplicationIcon::isEnabled() const
{
    if (priv->filename.isEmpty()) {
        return false;
    }

    QFile file(priv->filename);
    if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
        return false;
    }

    QString execLine = QString(QLatin1String("Exec=\"%1\"")).arg(QCoreApplication::applicationFilePath());
    QTextStream in(&file);
    while (!in.atEnd()) {
        QString line = in.readLine();
        if (line == execLine) {
            return true;
        }
    }

    return false;
}

void MUnixApplicationIcon::setEnabled(bool enabled)
{
    if (priv->filename.isEmpty()) {
        return;
    }

    if (isEnabled() == enabled) {
        return;
    }

    if (enabled) {
        QStringList lines;
        lines << QLatin1String("#!/usr/bin/env xdg-open");
        lines << QLatin1String("[Desktop Entry]");
        lines << QLatin1String("VERSION=1.0");
        lines << QLatin1String("Terminal=false");
        lines << QLatin1String("Type=Application");
        lines << QString(QLatin1String("Name=%1")).arg(QCoreApplication::applicationName());
        lines << QString(QLatin1String("Icon=%1")).arg(priv->iconFilename);
        lines << QLatin1String("Hidden=false");
        lines << QLatin1String("Categories=Utility;");
        lines << QLatin1String("X-DBUS-StartupType=Unique");
        lines << QString(QLatin1String("Exec=\"%1\"")).arg(QCoreApplication::applicationFilePath());
        lines << QString(QLatin1String(""));

        QDir(QFileInfo(priv->filename).dir()).mkpath(QLatin1String("."));
        QFile desktopfile(priv->filename);

        if (desktopfile.open(QFile::WriteOnly | QIODevice::Text)) {
            QTextStream out(&desktopfile);
            out << lines.join('\n');
        }


        QString resIconfilename = QString(QLatin1String(":/icons/encfsmanager/96/%1.png"))
                                    .arg(QCoreApplication::applicationName().remove(QRegularExpression(QLatin1String("\\s*"))));
        QDir(QFileInfo(priv->iconFilename).dir()).mkpath(QLatin1String("."));
        QFile::copy(resIconfilename, priv->iconFilename);

    } else {
        QFile::remove(priv->filename);
        QFile::remove(priv->iconFilename);
    }

    if (enabled == isEnabled()) {
        emit isEnabledChanged(enabled);
    }
}

