#ifndef KEYSTORAGE_H
#define KEYSTORAGE_H

// Qt
#include <QObject>
#include <QSharedPointer>

class Stash;

class KeyStore : public QObject
{
    Q_OBJECT

public:
    explicit KeyStore(QObject *parent = nullptr);
    virtual ~KeyStore();

    static KeyStore* newKeyStore();
    static bool isAvailable() { return false; }
    static QString statusMessage() { return QLatin1String(); }

signals:
    void storePasswordFinished(bool success, const QString &message = QLatin1String());
    void retrievePasswordFinished(bool success, const QString &passwordOrMessage = QLatin1String());
    void deletePasswordFinished(bool success, const QString &message = QLatin1String());

public slots:
    virtual void storePassword(QSharedPointer<Stash> stash, const QString &password) { Q_UNUSED(stash) Q_UNUSED(password) }
    virtual void retrievePassword(QSharedPointer<Stash> stash) { Q_UNUSED(stash) }
    virtual void deletePassword(QSharedPointer<Stash> stash) { Q_UNUSED(stash) }
};

#endif // KEYSTORAGE_H
