#ifndef SETTINGS_H
#define SETTINGS_H

#include <QObject>

class Settings : public QObject
{
    Q_OBJECT

public:
    explicit Settings(QObject *parent = 0);
    ~Settings();

    static Settings &instance();
    void load();
    void save() const;

private:
    static Settings *m_instance;


// Saved properties ===============================================================================
public:
    Q_PROPERTY(bool trayIconStashGroups READ trayIconStashGroups WRITE setTrayIconStashGroups NOTIFY trayIconStashGroupsChanged)
    Q_PROPERTY(bool trayIconEnabled READ trayIconEnabled WRITE setTrayIconEnabled NOTIFY trayIconEnabledChanged)
    Q_PROPERTY(bool trayIconStartHidden READ trayIconStartHidden WRITE setTrayIconStartHidden NOTIFY trayIconStartHiddenChanged)
    Q_PROPERTY(bool managerShowStashGroups READ managerShowStashGroups WRITE setManagerShowStashGroups NOTIFY managerShowStashGroupsChanged)
    Q_PROPERTY(bool unmountAllOnExit READ unmountAllOnExit WRITE setUnmountAllOnExit NOTIFY unmountAllOnExitChanged)
    Q_PROPERTY(QString fileManagerCommand READ fileManagerCommand WRITE setFileManagerCommand NOTIFY fileManagerCommandChanged)
    Q_PROPERTY(QString mountAddedComand READ mountAddedComand WRITE setMountAddedComand NOTIFY mountAddedComandChanged)
    Q_PROPERTY(QString mountRemovedCommand READ mountRemovedCommand WRITE setMountRemovedCommand NOTIFY mountRemovedCommandChanged)
    Q_PROPERTY(QString baseDir READ baseDir WRITE setBaseDir NOTIFY baseDirChanged)
    Q_PROPERTY(QStringList stashGroups READ stashGroups WRITE setStashGroups NOTIFY stashGroupsChanged)
    Q_PROPERTY(bool showSidebar READ showSidebar WRITE setShowSidebar NOTIFY showSidebarChanged)
    Q_PROPERTY(bool isFirstRun READ isFirstRun WRITE setIsFirstRun NOTIFY isFirstRunChanged)
    Q_PROPERTY(bool isApplicationIconEnabled READ isApplicationIconEnabled WRITE setApplicationIconEnabled NOTIFY isApplicationIconEnabledChanged)
    Q_PROPERTY(bool isAutostartEnabled READ isAutostartEnabled WRITE setIsAutostartEnabled NOTIFY isAutostartEnabledChanged)

    bool trayIconStashGroups() const;
    bool trayIconEnabled() const;
    bool trayIconStartHidden() const;
    bool managerShowStashGroups() const;
    bool unmountAllOnExit() const;
    QString fileManagerCommand() const;
    QString mountAddedComand() const;
    QString mountRemovedCommand() const;
    QString baseDir() const;
    QStringList stashGroups() const;
    bool showSidebar() const;
    bool isFirstRun() const;
    bool isApplicationIconEnabled() const;
    bool isAutostartEnabled() const;

signals:
    void trayIconStashGroupsChanged(bool trayIconStashGroups);
    void trayIconEnabledChanged(bool trayIconEnabled);
    void trayIconStartHiddenChanged(bool trayIconStartHidden);
    void managerShowStashGroupsChanged(bool managerShowStashGroups);
    void unmountAllOnExitChanged(bool unmountAllOnExit);
    void fileManagerCommandChanged(const QString &fileManagerCommand);
    void mountAddedComandChanged(const QString &mountAddedComand);
    void mountRemovedCommandChanged(const QString &mountRemovedCommand);
    void baseDirChanged(const QString &baseDir);
    void stashGroupsChanged(const QStringList &stashGroups);
    void showSidebarChanged(bool showSidebar);
    void isFirstRunChanged(bool isFirstRun);
    void isApplicationIconEnabledChanged(bool isApplicationIconEnabled);
    void isAutostartEnabledChanged(bool isAutostartEnabled);

public slots:
    void setTrayIconStashGroups(bool trayIconStashGroups);
    void setTrayIconEnabled(bool trayIconEnabled);
    void setTrayIconStartHidden(bool trayIconStartHidden);
    void setManagerShowStashGroups(bool managerShowStashGroups);
    void setUnmountAllOnExit(bool unmountAllOnExit);
    void setFileManagerCommand(const QString &fileManagerCommand);
    void setMountAddedComand(const QString &mountAddedComand);
    void setMountRemovedCommand(const QString &mountRemovedCommand);
    void setBaseDir(const QString &baseDir);
    void setStashGroups(const QStringList &stashGroups);
    void setShowSidebar(bool showSidebar);
    void setIsFirstRun(bool isFirstRun);
    void setApplicationIconEnabled(bool isApplicationIconEnabled);
    void setIsAutostartEnabled(bool isAutostartEnabled);

private:
    bool m_trayIconStashGroups;
    bool m_trayIconEnabled;
    bool m_trayIconStartHidden;
    bool m_managerShowStashGroups;
    bool m_unmountAllOnExit;
    QString m_fileManagerCommand;
    QString m_mountAddedComand;
    QString m_mountRemovedCommand;
    QString m_baseDir;
    QStringList m_stashGroups;
    bool m_showSidebar;
    bool m_isFirstRun;
};

#endif // SETTINGS_H
