#include "mountstashpage.h"
#include "ui_mountstashpage.h"

// Qt
#include <QDebug>

// Core
#include "Core/settings.h"
#include "Core/stashmanager.h"
#include "Core/stash.h"

#include <MHelpBrowser>

MountStashPage::MountStashPage(const QSharedPointer<Stash> &stash, QWidget *parent) :
    QWizardPage(parent),
    ui(new Ui::MountStashPage),
    m_stash(stash),
    m_initialized(false)
{
    ui->setupUi(this);

    setPixmap(QWizard::LogoPixmap, QIcon::fromTheme(QLatin1String("document-decrypt")).pixmap(24,24));

    ui->label_help->setText(QString(QLatin1String("<html><a href=\"stashmount.html\">%1</a></html>")).arg(tr("Help")));

    ui->button_mount->setDisabled(m_stash->isBusy());
    ui->lineEdit_password->setDisabled(m_stash->isBusy());
    connect(m_stash.data(), &Stash::isBusyChanged, ui->button_mount, &MSpinnerPushButton::setDisabled);
    connect(m_stash.data(), &Stash::isBusyChanged, ui->lineEdit_password, &QLineEdit::setDisabled);
    connect(m_stash.data(), &Stash::isBusyChanged, ui->button_mount, &MSpinnerPushButton::setChecked);
    connect(m_stash.data(), &Stash::mountFinished, this, &MountStashPage::mountResult);
    ui->label->setText(tr("Please enter the password for\n%1").arg(stash->mountDir()));
}

MountStashPage::~MountStashPage()
{
    delete ui;
}

void MountStashPage::mountResult(bool success, const QString &message)
{
    if (success) {
        qobject_cast<QDialog*>(parent()->parent())->close();
    } else {
        ui->label_message->setText(QString(QStringLiteral("<span style=\"color:#ff0000;\">✘</span> ")) + message);
        ui->lineEdit_password->clear();
        ui->lineEdit_password->setFocus();
    }
}

void MountStashPage::on_lineEdit_password_returnPressed()
{
    ui->button_mount->click();
}

void MountStashPage::on_button_mount_clicked()
{
    if (ui->lineEdit_password->text().isEmpty()) {
        return;
    }

    StashManager::instance().mount(m_stash, ui->lineEdit_password->text());
}

void MountStashPage::on_button_cancel_clicked()
{
    if (m_stash->isBusy()) {
        StashManager::instance().cancel(m_stash);
    } else {
        qobject_cast<QDialog*>(parent()->parent())->reject();
    }
}

void MountStashPage::setVisible(bool visible)
{
    if (visible && !m_initialized) {
        m_initialized = true;

        ui->button_sidebar->setChecked(Settings::instance().showSidebar());
        connect(ui->button_sidebar, &QPushButton::toggled, &Settings::instance(), &Settings::setShowSidebar);
        connect(&Settings::instance(), &Settings::showSidebarChanged, ui->button_sidebar, &QPushButton::setChecked);

        ui->button_mount->setEnabled(!ui->lineEdit_password->text().isEmpty());
        connect(ui->lineEdit_password, &QLineEdit::textChanged, [this](const QString &password) {
            ui->button_mount->setEnabled(!password.isEmpty());
            if (!password.isEmpty()) {
                ui->label_message->clear();
            }
        });
    }

    QWizardPage::setVisible(visible);

    if (visible) {
        ui->lineEdit_password->setFocus();
    }
}

void MountStashPage::on_label_help_linkActivated(const QString &link)
{
    MHelpBrowser::open(link);
}
