#include "preferencespage.h"
#include "ui_preferencespage.h"

#include "Core/settings.h"
#include "../3rdparty/mtools/include/MTools/MUnixApplicationIcon"

#include <MHelpBrowser>

PreferencesPage::PreferencesPage(QWidget *parent) :
    QWizardPage(parent),
    ui(new Ui::PreferencesPage),
    m_initialized(false),
    m_size(QSize(1,1))
{
    ui->setupUi(this);

    setPixmap(QWizard::LogoPixmap, QIcon::fromTheme(QLatin1String("applications-system")).pixmap(24,24));

    ui->label_help->setText(QString(QLatin1String("<html><a href=\"preferences.html\">%1</a></html>")).arg(tr("Help")));
}

PreferencesPage::~PreferencesPage()
{
    delete ui;
}

void PreferencesPage::setVisible(bool visible)
{
    if (visible && !m_initialized) {
        m_initialized = true;

        ui->button_sidebar->setChecked(Settings::instance().showSidebar());
        connect(ui->button_sidebar, &QPushButton::toggled, &Settings::instance(), &Settings::setShowSidebar);
        connect(&Settings::instance(), &Settings::showSidebarChanged, ui->button_sidebar, &QPushButton::setChecked);

        ui->checkBox_applicationIcon->setVisible(!MUnixApplicationIcon().isGLoballyEnabled());
        ui->checkBox_applicationIcon->setChecked(Settings::instance().isApplicationIconEnabled());
        connect(&Settings::instance(), &Settings::isApplicationIconEnabledChanged, ui->checkBox_applicationIcon, &QCheckBox::setChecked);
        connect(ui->checkBox_applicationIcon, &QCheckBox::toggled, &Settings::instance(), &Settings::setApplicationIconEnabled);

        ui->checkBox_isAutostartEnabled->setChecked(Settings::instance().isAutostartEnabled());
        connect(&Settings::instance(), &Settings::isAutostartEnabledChanged, ui->checkBox_isAutostartEnabled, &QCheckBox::setChecked);
        connect(ui->checkBox_isAutostartEnabled, &QCheckBox::toggled, &Settings::instance(), &Settings::setIsAutostartEnabled);

        ui->checkBox_unmountAllOnExit->setChecked(Settings::instance().unmountAllOnExit());
        connect(&Settings::instance(), &Settings::unmountAllOnExitChanged, ui->checkBox_unmountAllOnExit, &QCheckBox::setChecked);
        connect(ui->checkBox_unmountAllOnExit, &QCheckBox::toggled, &Settings::instance(), &Settings::setUnmountAllOnExit);

        ui->checkBox_trayIconEnabled->setChecked(Settings::instance().trayIconEnabled());
        ui->checkBox_trayIconStartHidden->setEnabled(ui->checkBox_trayIconEnabled->isChecked());
        ui->checkBox_trayIconStashGroups->setEnabled(ui->checkBox_trayIconEnabled->isChecked());
        connect(&Settings::instance(), &Settings::trayIconEnabledChanged, ui->checkBox_trayIconEnabled, &QCheckBox::setChecked);
        connect(ui->checkBox_trayIconEnabled, &QCheckBox::toggled, &Settings::instance(), &Settings::setTrayIconEnabled);
        connect(ui->checkBox_trayIconEnabled, &QCheckBox::toggled, ui->checkBox_trayIconStartHidden, &QCheckBox::setEnabled);
        connect(ui->checkBox_trayIconEnabled, &QCheckBox::toggled, ui->checkBox_trayIconStashGroups, &QCheckBox::setEnabled);

        ui->checkBox_trayIconStartHidden->setChecked(Settings::instance().trayIconStartHidden());
        connect(&Settings::instance(), &Settings::trayIconStartHiddenChanged, ui->checkBox_trayIconStartHidden, &QCheckBox::setChecked);
        connect(ui->checkBox_trayIconStartHidden, &QCheckBox::toggled, &Settings::instance(), &Settings::setTrayIconStartHidden);

        ui->checkBox_trayIconStashGroups->setChecked(Settings::instance().trayIconStashGroups());
        connect(&Settings::instance(), &Settings::trayIconStashGroupsChanged, ui->checkBox_trayIconStashGroups, &QCheckBox::setChecked);
        connect(ui->checkBox_trayIconStashGroups, &QCheckBox::toggled, &Settings::instance(), &Settings::setTrayIconStashGroups);
    }

    if (visible) {
        m_size = QWizardPage::minimumSizeHint();
    } else {
        m_size = QSize(1,1);
    }

    QWizardPage::setVisible(visible);
}

QSize PreferencesPage::sizeHint() const
{
    return m_size;
}

QSize PreferencesPage::minimumSizeHint() const
{
    return m_size;
}

void PreferencesPage::on_label_help_linkActivated(const QString &link)
{
    MHelpBrowser::open(link);
}
