#include "stashcommandpage.h"
#include "ui_stashcommandpage.h"

#include <QDebug>

#include "Core/settings.h"
#include "Core/stash.h"

#include <MHelpBrowser>

StashCommandPage::StashCommandPage(const QSharedPointer<Stash> &stash, QWidget *parent) :
    QWizardPage(parent),
    ui(new Ui::StashCommandPage),
    m_stash(stash),
    m_initialized(false),
    m_size(QSize(1,1))
{
    ui->setupUi(this);

    setPixmap(QWizard::LogoPixmap, QIcon::fromTheme(QLatin1String("document-edit")).pixmap(24,24));

    ui->label_help->setText(QString(QLatin1String("<html><a href=\"stashcustomcommands.html\">%1</a></html>")).arg(tr("Help")));
}

StashCommandPage::~StashCommandPage()
{
    delete ui;
}

void StashCommandPage::setVisible(bool visible)
{
    if (visible && !m_initialized) {
        m_initialized = true;

        ui->button_sidebar->setChecked(Settings::instance().showSidebar());
        connect(ui->button_sidebar, &QPushButton::toggled, &Settings::instance(), &Settings::setShowSidebar);
        connect(&Settings::instance(), &Settings::showSidebarChanged, ui->button_sidebar, &QPushButton::setChecked);

        ui->lineEdit_preMountCommand->setText(m_stash->preMountCommand());
        //connect(m_stash.data(), &Stash::preMountCommandChanged, ui->lineEdit_preMountCommand, &QLineEdit::setText);
        connect(ui->lineEdit_preMountCommand, &QLineEdit::textChanged, m_stash.data(), &Stash::setPreMountCommand);

        ui->lineEdit_postMountCommand->setText(m_stash->postMountCommand());
        //connect(m_stash.data(), &Stash::postMountCommandChanged, ui->lineEdit_postMountCommand, &QLineEdit::setText);
        connect(ui->lineEdit_postMountCommand, &QLineEdit::textChanged, m_stash.data(), &Stash::setPostMountCommand);

        ui->lineEdit_preUnmountCommand->setText(m_stash->preUnmountCommand());
        //connect(m_stash.data(), &Stash::preUnmountCommandChanged, ui->lineEdit_preUnmountCommand, &QLineEdit::setText);
        connect(ui->lineEdit_preUnmountCommand, &QLineEdit::textChanged, m_stash.data(), &Stash::setPreUnmountCommand);

        ui->lineEdit_postUnmountCommand->setText(m_stash->postUnmountCommand());
        //connect(m_stash.data(), &Stash::postUnmountCommandChanged, ui->lineEdit_postUnmountCommand, &QLineEdit::setText);
        connect(ui->lineEdit_postUnmountCommand, &QLineEdit::textChanged, m_stash.data(), &Stash::setPostUnmountCommand);
    }

    if (visible) {
        m_size = QWizardPage::minimumSizeHint();
    } else {
        m_size = QSize(1,1);
    }

    QWizardPage::setVisible(visible);
}

QSize StashCommandPage::sizeHint() const
{
    return m_size;
}

QSize StashCommandPage::minimumSizeHint() const
{
    return m_size;
}

void StashCommandPage::on_label_help_linkActivated(const QString &link)
{
    MHelpBrowser::open(link);
}
