#include "stashinformationpage.h"
#include "ui_stashinformationpage.h"

// Qt
#include <QIcon>

// Core
#include "Core/settings.h"
#include <Core/stash.h>
#include <Core/stashmanager.h>

#include <MHelpBrowser>

StashInformationPage::StashInformationPage(const QSharedPointer<Stash> &stash, QWidget *parent) :
    QWizardPage(parent),
    ui(new Ui::StashInformationPage),
    m_stash(stash),
    m_initialized(false),
    m_size(QSize(1,1))
{
    ui->setupUi(this);

    setPixmap(QWizard::LogoPixmap, QIcon::fromTheme(QLatin1String("help-about")).pixmap(24,24));

    ui->label_help->setText(QString(QLatin1String("<html><a href=\"stashinformation.html\">%1</a></html>")).arg(tr("Help")));
}

StashInformationPage::~StashInformationPage()
{
    delete ui;
}

void StashInformationPage::setVisible(bool visible)
{
    if (visible && !m_initialized) {
        m_initialized = true;

        ui->button_sidebar->setChecked(Settings::instance().showSidebar());
        connect(ui->button_sidebar, &QPushButton::toggled, &Settings::instance(), &Settings::setShowSidebar);
        connect(&Settings::instance(), &Settings::showSidebarChanged, ui->button_sidebar, &QPushButton::setChecked);

        if (m_stash->isAvailable()) {
            ui->label_stashInformation->setText(StashManager::instance().info(m_stash));
        }
    }

    if (visible) {
        m_size = QWizardPage::minimumSizeHint();
    } else {
        m_size = QSize(1,1);
    }

    QWizardPage::setVisible(visible);
}

QSize StashInformationPage::sizeHint() const
{
    return m_size;
}

QSize StashInformationPage::minimumSizeHint() const
{
    return m_size;
}

void StashInformationPage::on_label_help_linkActivated(const QString &link)
{
    MHelpBrowser::open(link);
}
